@@ -11,8 +11,9 @@
  * strchr() but ignores comments and quoted strings.
  */
 
-extern int addr_addrspec (char *buf);
+/*extern int addr_addrspec (char *buf);*/
 extern int addr_domain (char *buf);
 extern int addr_localpart (char *buf);
+extern int addr_msgid (char *buf);
 extern char *addr_qstrchr (char *str, int find);
 extern int addr_unescape (char *from, char *to, int len);
