@@ -26,7 +26,7 @@
 #include <out.h>
 #include <format.h>
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: art.c 29 2004-04-24 23:02:38Z patrik $";
 
 struct fileobj *file_map (char *path)
 {
@@ -55,7 +55,7 @@ struct fileobj *file_map (char *path)
                {
                   close(fd);
                   fp->path = strcpy((char *) fp + sizeof (struct fileobj), path);
-                  return (fp);
+                  return fp;
                }
                else
                   LOG("file_map:%s has bad magic", path);
@@ -74,7 +74,7 @@ struct fileobj *file_map (char *path)
    }
    else if (ENOENT != errno)
       LOG("file_map:open(%s):%m", path);
-   return (NULL);
+   return NULL;
 }
 
 static void file_unmap (void *p)
@@ -90,7 +90,7 @@ static int file_cmp (void *a, void *b)
    struct fileobj *x = (struct fileobj *) a;
    struct fileobj *y = (struct fileobj *) b;
 
-   return (strcmp(x->path, y->path));
+   return strcmp(x->path, y->path);
 }
 
 static int desc = -1;
@@ -101,9 +101,9 @@ static int file_init (void)
    if (-1 == desc)
    {
       LOG("file_init:%m");
-      return (-1);
+      return -1;
    }
-   return (0);
+   return 0;
 }
 
 static struct file *file_gimme (char *name, int *size)
@@ -116,7 +116,7 @@ static struct file *file_gimme (char *name, int *size)
    if (NULL == (fp = cache_find(desc, &f)))
    {
       if (NULL == (fp = file_map(name)))
-         return (NULL);
+         return NULL;
       else
          cache_insert(desc, fp);
    }
@@ -134,7 +134,7 @@ static struct file *file_gimme (char *name, int *size)
  Should dereference aliased articles also.
  *************************************************************/
 
-static int file_initialized = 0;
+static bool file_initialized = FALSE;
 
 int art_gimmenoderef (char *group, int serial, struct article *ap)
 {
@@ -146,16 +146,16 @@ int art_gimmenoderef (char *group, int serial, struct article *ap)
    int filesize, lim;
 
    if (serial < 0)
-      return (-1);
+      return -1;
    if (strlen(group) >= GROUPNAMELEN)
-      return (-1);
+      return -1;
 
    if (!file_initialized)
    {
       if (-1 == file_init())
-         return (-1);
+         return -1;
       else
-         file_initialized = 1;
+         file_initialized = TRUE;
    }
 
    filenumber = serial / ARTSPERFILE;
@@ -168,12 +168,12 @@ int art_gimmenoderef (char *group, int serial, struct article *ap)
    do
    {
       if (!(f = file_gimme(path, &filesize)))
-         return (-1);
+         return -1;
       lim = f->info[part].boffset + f->info[part].blen;
       if (lim <= 0)
       {
          errno = ENOENT;
-         return (-1);
+         return -1;
       }
       if (lim <= filesize)
          break;
@@ -186,17 +186,17 @@ int art_gimmenoderef (char *group, int serial, struct article *ap)
       }
 
       if (!(f = file_gimme(path, &filesize)))
-         return (-1);
+         return -1;
       lim = f->info[part].boffset + f->info[part].blen;
       if (lim <= 0)
       {
          errno = ENOENT;
-         return (-1);
+         return -1;
       }
       if (lim <= filesize)
          break;
       LOG("art_gimmenoderef:body extends beyond file in %s:%d", group, serial);
-      return (-1);
+      return -1;
    }
    while (0);
 
@@ -208,31 +208,31 @@ int art_gimmenoderef (char *group, int serial, struct article *ap)
       if (0 == info.hoffset)
       { /* unused */
          if (info.boffset)
-            log("art_gimmenoderef:corrupted index in %s:%d", group, serial);
+            LOG("art_gimmenoderef:corrupted index in %s:%d", group, serial);
       }
       else if (info.hoffset < 0) /* cancelled */
          if (info.boffset >= 0)
-            log("art_gimmenoderef:bad cancel in %s:%d", group, serial);
-      return (-1);
+            LOG("art_gimmenoderef:bad cancel in %s:%d", group, serial);
+      return -1;
    }
    if (info.blen < 2 || info.hlen <= 11)
    {
-      log("art_gimmenoderef:Corrupted index in %s:%d", group, serial);
-      return (-1);
+      LOG("art_gimmenoderef:Corrupted index in %s:%d", group, serial);
+      return -1;
    }
 
    ap->head = (char *) f + info.hoffset + 1;
    ap->hlen = info.hlen - 2;
    if (ap->head[-1] /* || ap->head[ap->hlen] */ )
    {
-      log("art_gimmenoderef:Bad header in %s:%d", group, serial);
-      return (-1);
+      LOG("art_gimmenoderef:Bad header in %s:%d", group, serial);
+      return -1;
    }
 
    ap->body = (char *) f + f->info[part].boffset + 1;
    ap->blen = f->info[part].blen - 2;
 
-   return (0);
+   return 0;
 }
 
 int art_gimme (char *group, int serial, struct article *ap)
@@ -254,12 +254,12 @@ int art_gimme (char *group, int serial, struct article *ap)
       if (deref >= 10)
       {
          LOG1("Too many aliases under %s:%d", g, s);
-         return (-1);
+         return -1;
       }
       if (-1 == art_gimmenoderef(group, serial, ap))
-         return (-1);
+         return -1;
       if (-1 == ap->blen)
-         return (-1); /* canceled */
+         return -1; /* canceled */
       /*
        * If its an alias, the body will be empty and the
        * head will contain only one field:
@@ -267,7 +267,7 @@ int art_gimme (char *group, int serial, struct article *ap)
        * We ignore the messageid part.
        */
       if (ap->blen > 0 && strncmp(ap->head, "Message-ID:", 11))
-         return (0); /* found */
+         return 0; /* found */
       /* is alias */
       for (p = ap->head + 11; ' ' == *p; p++) ;
       lim = ngroup + sizeof (ngroup);
@@ -285,8 +285,8 @@ int art_gimme (char *group, int serial, struct article *ap)
          break;
       group = ngroup; /* serial already set */
    }
-   log("art_gimme:bad alias under %s:%d", g, s);
-   return (-1);
+   LOG("art_gimme:bad alias under %s:%d", g, s);
+   return -1;
 }
 
 void art_filecachestat (int *hit, int *miss)
@@ -302,11 +302,11 @@ static int getfield (char *buf, struct field *f)
    if (!*cp)
    {
       f->pointer = NULL;
-      return (0);
+      return 0;
    }
    f->len = strcspn(cp, "\r\n");
    if (!f->len)
-      return (0);
+      return 0;
    f->pointer = cp;
    return ((cp + f->len) - buf);
 }
@@ -323,7 +323,7 @@ int art_makexover (struct article *ap, struct xover *xp)
    char *cp;
 
    if (NULL == ap || NULL == ap->head || NULL == xp)
-      return (-1);
+      return -1;
 
    cp = ap->head;
 
@@ -373,7 +373,7 @@ start:
    }
 
    *xp = x;
-   return (0);
+   return 0;
 }
 
 char *art_findfield (char *head, char *fieldname)
@@ -405,8 +405,8 @@ enter:
          start += strspn(start, " \t\r\n\f");
          for (cp = start; *cp && '\r' != *cp; cp++) ;
          b_appendl(&b, start, cp - start);
-         return (b.buf);
+         return b.buf;
       }
    }
-   return ("");
+   return "";
 }
