@@ -33,7 +33,7 @@
 #include <out.h>
 #include <format.h>
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: commands.c 29 2004-04-24 23:02:38Z patrik $";
 
 #define putdot() args_write(1, ".\r\n")
 
@@ -76,12 +76,12 @@ static int readspec (char *spec)
    {
       if ((specgroup = currentgroup))
          if ((spechi = speclo = currentserial) > 0)
-            return (0);
+            return 0;
          else
             specerror = "420 No article selected\r\n";
       else
          specerror = "412 No group selected\r\n";
-      return (-1);
+      return -1;
    }
 
    if ('<' == *spec)
@@ -96,14 +96,14 @@ static int readspec (char *spec)
          {
             spechi = speclo = d.serial;
             specgroup = d.newsgroup; /* is static */
-            return (0);
+            return 0;
          }
          else
             specerror = "430 No such article\r\n";
       }
       else
          specerror = "430 Invalid message ID\r\n";
-      return (-1);
+      return -1;
    }
 
    if ((specgroup = currentgroup))
@@ -138,11 +138,11 @@ static int readspec (char *spec)
       else
          goto invalid;
    }
-   return (0);
+   return 0;
 
 invalid:
    specerror = "501 Invalid range\r\n";
-   return (-1);
+   return -1;
 }
 
 static char *findid (void)
@@ -150,8 +150,8 @@ static char *findid (void)
    char *id;
 
    if ((id = art_findfield(article.head, "Message-ID")) && *id)
-      return (id);
-   return ("<0>");
+      return id;
+   return "<0>";
 }
 
 /*
@@ -378,7 +378,7 @@ void do_newgroups (void)
             formats(buf, sizeof (buf) - 1, "%s/.created", group);
             if (-1 == stat(buf, &st))
             {
-               log("do_newsgroups:stat(%s/.created):%m", group);
+               LOG("do_newsgroups:stat(%s/.created):%m", group);
                continue;
             }
             if (st.st_mtime >= cutoff)
