@@ -71,10 +71,10 @@ do { char * p; int i; \
 
 extern int debug;
 
-#define LOG log
-#define LOG1 if (debug >= 1) log
-#define LOG2 if (debug >= 2) log
-#define LOG3 if (debug >= 3) log
+#define LOG log_
+#define LOG1 if (debug >= 1) log_
+#define LOG2 if (debug >= 2) log_
+#define LOG3 if (debug >= 3) log_
 #define FAIL fail
 
 #include <sys/param.h>
@@ -94,6 +94,8 @@ extern int debug;
 
 #define JUNK_GROUP "=junk"
 
+#undef FALSE   /* Mac OS X apparently defines these */
+#undef TRUE
 typedef enum { FALSE, TRUE } bool;
 
 #endif /* CONFIG_H */
