@@ -23,23 +23,23 @@
 #include <out.h>
 #include <nap.h>
 
+static const char ver_ctrl_id[] = "$Id: dh_find.c 56 2004-07-27 16:54:48Z patrik $";
+
 int dh_fd = -1;
 
 char dh_tablefile[sizeof (DH_TABLEFILE) + 32];
 char dh_chainfile[sizeof (DH_TABLEFILE) + 32];
 char dh_groupfile[sizeof (DH_GROUPFILE) + 32];
 char dh_tmp[sizeof (DH_GROUPFILE) + 32];
-int dh_isreadonly = 0;
-
-static const char rcsid[] = "$Id$";
+bool dh_isreadonly = FALSE;
 
 struct table *dh_table = NULL;
 
 /* General string hashing function, taken from djb */
 
-unsigned int dhhash (char *buf)
+unsigned dhhash (char *buf)
 {
-   unsigned int h;
+   unsigned h;
    int len = strlen(buf);
 
    h = 5381;
@@ -47,7 +47,7 @@ unsigned int dhhash (char *buf)
    {
       --len;
       h += (h << 5);
-      h ^= (unsigned int) *buf++;
+      h ^= (unsigned) *buf++;
    }
    return (h % DH_SIZE);
 }
@@ -65,20 +65,20 @@ int dhlock (void)
 
    for (i = 100; i--;)
    {
-      if (0 == lockf(dh_fd, F_TLOCK, 0))
-         return (0);
-      if (EAGAIN != errno)
-         return (-1);
+      if (lockf(dh_fd, F_TLOCK, 0) == 0)
+         return 0;
+      if (errno != EAGAIN)
+         return -1;
       nap(0, 500);
    }
-   return (-1);
+   return -1;
 }
 
 int dhunlock (void)
 {
    lseek(dh_fd, 0, SEEK_SET);
    lockf(dh_fd, F_ULOCK, 0);
-   return (0);
+   return 0;
 }
 
 struct chain *dhlocatechain (char *messageid)
@@ -91,15 +91,15 @@ struct chain *dhlocatechain (char *messageid)
    h = dhhash(messageid);
    x = dh_table->next + h * 3;
    index = char3toint(x);
-   if (!index)
-      return (NULL);
+   if (index == 0)
+      return NULL;
 
    chp = allo_deref(index);
-   if (NULL == chp)
+   if (chp == NULL)
    {
       LOG("dhlocatechain:bad allo deref");
    }
-   return (chp);
+   return chp;
 }
 
 static int initfile (void)
@@ -110,55 +110,55 @@ static int initfile (void)
    char foo[3] = { '\0', };
 
    fd = open(dh_tablefile, O_RDWR | O_CREAT | O_EXCL, 0644);
-   if (-1 == fd)
-      return (-1);
-   if (-1 == lockf(fd, F_TLOCK, 0))
+   if (fd == -1)
+      return -1;
+   if (lockf(fd, F_TLOCK, 0) == -1)
    {
       do
       { /* wait until other process has initialized it */
-         if (EAGAIN == errno)
+         if (errno == EAGAIN)
             nap(0, 200);
          else
             goto fail;
       }
-      while (-1 == lockf(fd, F_TLOCK, 0));
+      while (lockf(fd, F_TLOCK, 0) == -1);
       lockf(fd, F_ULOCK, 0);
-      return (fd);
+      return fd;
    }
-   if (sizeof (int) != write(fd, &integer, sizeof (int)))
+   if (write(fd, &integer, sizeof (int)) != sizeof (int))
       goto fail;
    for (i = 0; i < DH_SIZE; i++)
-      if (sizeof (foo) != write(fd, foo, sizeof (foo)))
+      if (write(fd, foo, sizeof (foo)) != sizeof (foo))
          goto fail;
    lseek(fd, 0, SEEK_SET);
    lockf(fd, F_ULOCK, 0);
-   return (fd);
+   return fd;
 
 fail:
    if (fd > -1)
       close(fd);
-   return (-1);
+   return -1;
 }
 
-int dh_find (struct data *dp, int readonly)
+int dh_find (struct data *dp, bool readonly)
 {
    struct chain *chp;
    unsigned char *x;
 
    if (!readonly)   /* lockf() fails on read-only file, and locking not needed anyway for R/O? */
-      if (-1 == dhlock())
-         return (-1);
+      if (dhlock() == -1)
+         return -1;
    chp = dhlocatechain(dp->messageid);
-   if (!chp)
+   if (chp == NULL)
       goto fail;
-   while (strcmp(dp->messageid, chp->messageid))
+   while (strcmp(dp->messageid, chp->messageid) != 0)
    {
       unsigned index = chp->next;
 
-      if (!index)
+      if (index == 0)
          goto fail;
       chp = allo_deref(index);
-      if (!chp)
+      if (chp == NULL)
       {
          LOG2("dh_find:bad allo deref");
          goto fail;
@@ -167,11 +167,11 @@ int dh_find (struct data *dp, int readonly)
    dp->serial = chp->serial;
    x = (unsigned char *) chp->newsgroup;
    dp->newsgroup = ng_newsgroup(char2toint(x));
-   if (!dp->newsgroup)
+   if (dp->newsgroup == NULL)
       goto fail;
    if (!readonly)
       dhunlock();
-   return (0);
+   return 0;
 
 fail:
    if (!readonly)
@@ -179,7 +179,7 @@ fail:
    return -1;
 }
 
-int dh_open (char *pre, int readonly)
+int dh_open (char *pre, bool readonly)
 {
    struct stat st;
    int prot;
@@ -190,7 +190,7 @@ int dh_open (char *pre, int readonly)
       if (strlen(pre) > 27)
       {
          LOG("SNROOT too long");
-         return (-1);
+         return -1;
       }
       strcpy(dh_tablefile, pre);
       strcat(dh_tablefile, DH_TABLEFILE);
@@ -215,46 +215,46 @@ int dh_open (char *pre, int readonly)
    else
       openflag = O_RDONLY;
 
-   if (-1 == (dh_fd = open(dh_tablefile, openflag)))
+   if ((dh_fd = open(dh_tablefile, openflag)) == -1)
    {
-      if (ENOENT == errno)
+      if (errno == ENOENT)
       {
-         if (-1 == (dh_fd = initfile()))
+         if ((dh_fd = initfile()) == -1)
          {
             LOG("dh_open:Can't create %s: %m", dh_tablefile);
-            return (-1);
+            return -1;
          }
       }
       else
       {
          LOG("dh_open:Can't open %s: %m", dh_tablefile);
-         return (-1);
+         return -1;
       }
    }
 
-   if (-1 == ng_init())
+   if (ng_init() == -1)
       goto fail;
 
    dh_table = (struct table *) mmap(0, sizeof (struct table), prot, MAP_SHARED, dh_fd, 0);
 
-   if (!dh_table || dh_table == MAP_FAILED)
+   if (dh_table == NULL || dh_table == MAP_FAILED)
    {
       LOG("dh_open:mmap:%m?");
-      dh_table = 0;
+      dh_table = NULL;
    }
    else if (dh_table->magic != DH_MAGIC)
       LOG("dh_open:Bad magic");
-   else if (-1 == fstat(dh_fd, &st))
+   else if (fstat(dh_fd, &st) == -1)
       LOG("dh_open:fstat:%m");
-   else if (sizeof (struct table) != st.st_size)
+   else if (st.st_size != sizeof (struct table))
       LOG("dh_open:table has wrong size!");
-   else if (-1 == allo_init(dh_chainfile, openflag) &&
-            -1 == allo_init(dh_chainfile, openflag | O_CREAT))
+   else if (allo_init(dh_chainfile, openflag) == -1 &&
+            allo_init(dh_chainfile, openflag | O_CREAT) == -1)
    {
       LOG("dh_open:allo_init(%s):%m?", dh_chainfile);
    }
    else
-      return (0);
+      return 0;
    if (dh_table)
    {
       munmap(dh_table, sizeof (struct table));
@@ -264,7 +264,8 @@ int dh_open (char *pre, int readonly)
 
 fail:
    close(dh_fd);
-   return (dh_fd = -1);
+   dh_fd = -1;
+   return dh_fd;
 }
 
 int dh_close (void)
@@ -274,12 +275,12 @@ int dh_close (void)
       close(dh_fd);
       dh_fd = -1;
    }
-   if (dh_table)
+   if (dh_table != NULL)
    {
       munmap((caddr_t) dh_table, sizeof (struct table));
       dh_table = NULL;
    }
    allo_destroy();
    ng_fin();
-   return (0);
+   return 0;
 }
