@@ -42,10 +42,10 @@ struct data {
  * only dp->messageid is used.  All returned values are readonly.
  */
 
-extern int dh_open (char *pre, int readonly);
+extern int dh_open (char *pre, bool readonly);
 extern int dh_close (void);
 extern int dh_insert (struct data *dp);
-extern int dh_find (struct data *dp, int readonly);
+extern int dh_find (struct data *dp, bool readonly);
 extern int dh_delete (struct data *dp);
 
 /* Stuff to link in with sndumpdb */
@@ -59,8 +59,8 @@ struct chain {
 
 #define DH_MAGIC 0xd0bed00
 
-#define char2toint(p) ((p[0]<<8)|p[1])
-#define char3toint(p) (((p)[0]<<18)|((p)[1]<<10)|((p)[2]<<2))
+#define char2toint(p) ((p[0] << 8) | p[1])
+#define char3toint(p) (((p)[0] << 18) | ((p)[1] << 10) | ((p)[2] << 2))
 
 struct table {
    int magic;
