@@ -9,30 +9,29 @@
  * Check the field name of a header line.
  */
 
+static const char ver_ctrl_id[] = "$Id: field.c 52 2004-07-26 16:12:16Z patrik $";
+
 int check_field (char *field, int len)
 {
    int i;
 
    for (i = 0; i < len; i++)
    {
-      if (field[i] >= 'a' && field[i] <= 'z')
+      /* Allow printable US-ASCII characters, except colon */
+      if (field[i] >= '!' && field[i] <= '9')
          continue;
-      if (field[i] >= 'A' && field[i] <= 'Z')
+      if (field[i] >= ';' && field[i] <= '~')
          continue;
-      if (field[i] >= '0' && field[i] <= '9')
-         continue;
-      if ('-' == field[i])
-         continue;
-      if (':' == field[i])
-         return (i);
-      if (' ' == field[i] || '\t' == field[i])
+      if (field[i] == ':')
+         return i;
+      if (field[i] == ' ' || field[i] == '\t')
          break;
-      return (0);
+      return 0;
    }
    do
       i++;
    while (field[i] == ' ' || field[i] == '\t');
-   if (':' != field[i])
-      return (0);
-   return (i);
+   if (field[i] != ':')
+      return 0;
+   return i;
 }
