@@ -36,6 +36,8 @@
 #include <format.h>
 #include <opt.h>
 
+static const char ver_ctrl_id[] = "$Id: get.c 36 2004-04-27 16:52:02Z patrik $";
+
 struct job {
    int pid;
    int sd;
@@ -49,14 +51,12 @@ struct job {
    char group[1];
 };
 
-static const char rcsid[] = "$Id$";
-
 /* opt* values are propagated to children */
-char *optdebug = 0;
-char *optpipelining = 0;
-char *optmax = 0;     /* only for priming a group (serial == 0) */
-int optlogpid = 0;
-int optnocache = 0;   /* internal option */
+char *optdebug = NULL;
+char *optpipelining = NULL;
+char *optmax = NULL;     /* only for priming a group (serial == 0) */
+bool optlogpid = FALSE;
+bool optnocache = FALSE;   /* internal option */
 int throttlerate = 0;
 int concurrency = 4;
 
@@ -81,11 +81,11 @@ static int atou (char *buf)
    {
       c = *buf - '0';
       if (c > 9 || c < 0)
-         return (-1);
+         return -1;
       i *= 10;
       i += c;
    }
-   return (i);
+   return i;
 }
 
 /* --------------------------------------------------
@@ -106,21 +106,21 @@ static int store_get (void)
       if (pid <= 0)
       {
          if (-19 == pid)
-            log("store_get:exec snstore:PATH set?");
+            LOG("store_get:exec snstore:PATH set?");
          else if (-1 == pid)
-            log("store_get:exec snstore:%m?");
+            LOG("store_get:exec snstore:%m?");
          else
-            log("store_get:snstore exited with %d", 0 - pid);
-         return (-1);
+            LOG("store_get:snstore exited with %d", 0 - pid);
+         return -1;
       }
       fcntl(*stores, F_SETFD, 1);
       nstores++;
       LOG3("pipe %d is snstore pid %d", *stores, pid);
    }
-   return (stores[--nstores]);
+   return stores[--nstores];
 }
 
-static void store_put(int fd)
+static void store_put (int fd)
 {
    if (nstores < MAX_CONCURRENCY)
       stores[nstores++] = fd;
@@ -157,7 +157,7 @@ static int sock_get (char *server, int port, unsigned long *addrp, int *reused)
             nsocks--;
             if (i != nsocks)
                socks[i] = socks[nsocks];
-            return (sd);
+            return sd;
          }
 
    /* XXX We could be passing a socket that isn't fully connected yet. */
@@ -183,18 +183,18 @@ static int sock_get (char *server, int port, unsigned long *addrp, int *reused)
          {
             fcntl(sd, F_SETFL, fl);
             fcntl(sd, F_SETFD, 1);
-            return (sd);
+            return sd;
          }
          else
-            log("sock_get:connect to %s:%m?", server);
+            LOG("sock_get:connect to %s:%m?", server);
       }
       else
-         log("sock_get:resolve \"%s\"", server);
+         LOG("sock_get:resolve \"%s\"", server);
       close(sd);
    }
    else
-      log("sock_get:socket to %s:%m", server);
-   return (-1);
+      LOG("sock_get:socket to %s:%m", server);
+   return -1;
 }
 
 static void sock_put (int sd, char *server, unsigned long addr, int port)
@@ -221,7 +221,7 @@ static void sock_put (int sd, char *server, unsigned long addr, int port)
  * 4: end of space (qsize)
  */
 
-static struct job **queue = 0;
+static struct job **queue = NULL;
 static int toff = 0;
 static int tend = 0;
 static int qsize;
@@ -235,7 +235,7 @@ static int queue_add (struct job *jp)
 
       newsize = (queue ? (qsize * 2) : 20);
       if (!(tmp = malloc(newsize * sizeof (struct job *))))
-         return (-1);
+         return -1;
       if (queue)
       {
          memcpy(tmp, queue, qsize * sizeof (struct job *));
@@ -245,7 +245,7 @@ static int queue_add (struct job *jp)
       qsize = newsize;
    }
    queue[tend++] = jp;
-   return (0);
+   return 0;
 }
 
 static void swap (int a, int b)
@@ -304,7 +304,7 @@ static int similarity (char *g1, char *g2)
             break;
       while ('.' != *g1++) ;
    }
-   return (score);
+   return score;
 }
 
 /*
@@ -320,9 +320,9 @@ static int queue_getnext (void)
    switch ((max = tend - toff))
    {
       case 0:
-         return (-1);
+         return -1;
       case 1:
-         return (toff);
+         return toff;
       default:
          max = 4;
       case 2:
@@ -345,7 +345,7 @@ static int queue_getnext (void)
          bestgroup = t;
       }
    }
-   return (bestgroup);
+   return bestgroup;
 }
 
 /* --------------------------------------------------
@@ -365,7 +365,7 @@ int throttle_setfds (fd_set * rs)
          if (queue[i]->sd > max)
             max = queue[i]->sd;
       }
-   return (max);
+   return max;
 }
 
 /*
@@ -408,7 +408,7 @@ void throttle (fd_set * rs)
          tv.tv_sec = sec;
          tv.tv_usec = usec;
          if (sec >= 0)
-            select(0, 0, 0, 0, &tv);
+            select(0, NULL, NULL, NULL, &tv);
       }
       bytes = 0;
    }
@@ -421,7 +421,7 @@ void throttle (fd_set * rs)
          {
             if (-1 == write(queue[i]->infd, buf, c))
             {
-               log("throttle:pipe to %s:%m", queue[i]->group);
+               LOG("throttle:pipe to %s:%m", queue[i]->group);
                close(queue[i]->infd);
                queue[i]->infd = -1;
             }
@@ -457,7 +457,7 @@ static void readfile (char *dir, char *fn, char buf[20])
             }
             if (buf[i] < '0' || buf[i] > '9')
             {
-               log("readfile:bad value in %s/%s", dir, fn);
+               LOG("readfile:bad value in %s/%s", dir, fn);
                *buf = '\0';
                return;
             }
@@ -465,10 +465,10 @@ static void readfile (char *dir, char *fn, char buf[20])
          return;
       }
       else
-         log("readfile:read %s:%m", path1);
+         LOG("readfile:read %s:%m", path1);
    }
    else if (ENOENT != errno)
-      log("readfile:open %s:%m", path1);
+      LOG("readfile:open %s:%m", path1);
    *buf = '\0';
 }
 
@@ -478,27 +478,27 @@ int reap (void)
    struct job *jp;
 
    if (toff <= 0 || (pid = waitpid(-1, &ex, WNOHANG)) <= 0)
-      return (1);
+      return 1;
 
    for (j = toff - 1; j > -1 && pid != queue[j]->pid; j--) ;
    if (-1 == j)
-      return (1);
+      return 1;
 
    jp = queue[j];
    if (WIFEXITED(ex))
    {
       if ((ex = WEXITSTATUS(ex)))
-         log("reap:job %s exited %d", jp->group, ex);
+         LOG("reap:job %s exited %d", jp->group, ex);
    }
    else if (WIFSIGNALED(ex))
    {
-      log("reap:job %s caught signal %d", jp->group, ex = WTERMSIG(ex));
+      LOG("reap:job %s caught signal %d", jp->group, ex = WTERMSIG(ex));
       ex = 0 - ex;
    }
    else
    {
       ASSERT(0)
-      return (1);
+      return 1;
    }
 
    /*
@@ -522,7 +522,7 @@ int reap (void)
    {
       jp->infd = jp->sd = jp->outfd = jp->pid = -1;
       queue_run2todo(j);
-      return (1);
+      return 1;
    }
    if (0 == ex)
    {
@@ -530,23 +530,23 @@ int reap (void)
       formats(path2, sizeof (path2) - 1, "%s/.serial", jp->group);
       if (-1 == rename(path1, path2))
          if (ENOENT != errno)
-            log("reap:rename %s, %s:%m", path1, path2);
+            LOG("reap:rename %s, %s:%m", path1, path2);
    }
    else
-      log("reap:Giving up on %s", jp->group);
+      LOG("reap:Giving up on %s", jp->group);
    queue_rm(j);
-   return (0);
+   return 0;
 }
 
-int sigchld = 0;
+bool sigchld = FALSE;
 
-static void chldhand (int x) { sigchld = 1; }
+static void chldhand (int x) { sigchld = TRUE; }
 
-int sigusr = 0;
+bool sigusr = FALSE;
 
 static void usrhand (int u)
 {
-   sigusr = 1;
+   sigusr = TRUE;
    if (SIGUSR1 == u)
    {
       if (throttlerate > 1)
@@ -577,9 +577,9 @@ int sow (void)
    char envtimeout[20 + sizeof ("TIMEOUT=")];
 
    if (toff >= concurrency)
-      return (1);
+      return 1;
    if (-1 == (j = queue_getnext()))
-      return (1);
+      return 1;
    jp = queue[j];
    jp->attempts++;
 
@@ -603,20 +603,20 @@ int sow (void)
                   else
                      jp->infd = -1;
                   queue_todo2run(j);
-                  return (0);
+                  return 0;
                }
                else
-                  log("sow:fork for %s:%m", jp->group);
+                  LOG("sow:fork for %s:%m", jp->group);
             }
             else
-               log("sow:pipe for %s:%m", jp->group);
+               LOG("sow:pipe for %s:%m", jp->group);
             close(jp->sd); /* Can't reuse, not logged in */
             jp->sd = -1;
          }
          store_put(jp->outfd);
          jp->outfd = -1;
       }
-      return (-1);
+      return -1;
    }
    while (0);
 
@@ -685,9 +685,9 @@ int sow (void)
       int pid, s;
       fd_set set;
 
-      sigchld = 0;
+      sigchld = FALSE;
       if (-1 == (pid = fork()))
-         fail(2, "Can't fork for HELLO:%m");
+         fail(2, "Can't fork for SNHELLO:%m");
       if (0 == pid)
       {
          char *v[2];
@@ -696,9 +696,9 @@ int sow (void)
             fail(2, "chdir(%s/.outgoing):%m", jp->group);
          fixfd(2, 1);
          v[1] = 0;
-         *v = "./.HELLO";
+         *v = "./.SNHELLO";
          execv(*v, v);
-         *v = "HELLO";
+         *v = "SNHELLO";
          execvp(*v, v);
          fail(2, "Can't exec %s:%m", *v);
       }
@@ -710,10 +710,10 @@ int sow (void)
          tv.tv_sec = tmo;
          tv.tv_usec = 0;
          FD_SET(jp->sd, &set);
-         if (select(jp->sd + 1, &set, 0, 0, &tv))
+         if (select(jp->sd + 1, &set, NULL, NULL, &tv))
          {
             tv.tv_sec = 2;
-            select(0, 0, 0, 0, &tv);
+            select(0, NULL, NULL, NULL, &tv);
          }
          else
             kill(pid, SIGALRM);
@@ -727,12 +727,12 @@ int sow (void)
       if (WIFEXITED(s))
       {
          if ((s = WEXITSTATUS(s)))
-            fail(2, "HELLO(%s) exited %d", jp->group, s);
+            fail(2, "SNHELLO(%s) exited %d", jp->group, s);
       }
       else if (WIFSIGNALED(s))
-         fail(2, "HELLO(%s) caught signal %d", jp->group, WTERMSIG(s));
+         fail(2, "SNHELLO(%s) caught signal %d", jp->group, WTERMSIG(s));
       else
-         fail(2, "HELLO(%s) unknown wait status %d", jp->group, s);
+         fail(2, "SNHELLO(%s) unknown wait status %d", jp->group, s);
    }
 
    readfile(".", ".serial", serialbuf);
@@ -754,7 +754,7 @@ int sow (void)
    execvp("snfetch", argv_snfetch);
    fail(19, "sow:can't exec snfetch for %s:%m", jp->group);
    /* Not Reached */
-   return (-1);
+   return -1;
 }
 
 void init (void)
@@ -789,7 +789,7 @@ int add (char *group)
       unsigned short port;
       char server[1];
    };
-   static struct s *servers = 0;
+   static struct s *servers = NULL;
    struct job *jp;
    int c, port;
    char *p;
@@ -828,30 +828,30 @@ int add (char *group)
                jp->sd = jp->outfd = jp->pid = jp->infd = -1;
                jp->attempts = 0;
                if (0 == queue_add(jp))
-                  return (0);
+                  return 0;
                free(jp);
             }
-            log("add:No memory");
+            LOG("add:No memory");
          }
          else
-            log("add:%s has bad server symlink", group);
+            LOG("add:%s has bad server symlink", group);
       }
       else
-         log("add:%s server symlink missing port", group);
+         LOG("add:%s server symlink missing port", group);
    }
    else
-      log("add:Can't read symlink in %s:%m", group);
-   return (-1);
+      LOG("add:Can't read symlink in %s:%m", group);
+   return -1;
 }
 
-int jobs_not_done (void) { return (tend); }
+int jobs_not_done (void) { return tend; }
 
 /*
  * Rather cavalier about not reaping snstore processes.
  * When not shutting down, reap() will wait for any.
  */
 
-void quit(void)
+void quit (void)
 {
    if (nstores)
       do
