@@ -13,8 +13,8 @@
 extern char *optdebug;
 extern char *optpipelining;
 extern char *optmax;
-extern int optlogpid;
-extern int optnocache;
+extern bool optlogpid;
+extern bool optnocache;
 extern int throttlerate;
 extern int concurrency;
 
@@ -25,8 +25,8 @@ extern void throttle (fd_set * rs);
 extern int reap (void);
 extern int sow (void);
 
-extern int sigchld;
-extern int sigusr;
+extern bool sigchld;
+extern bool sigusr;
 
 extern void init (void);
 extern int add (char *group);
