@@ -8,13 +8,15 @@
 #ifndef GROUP_H
 #define GROUP_H
 
+#include "config.h"
+
 /* This doesn't do much */
 
 struct group {
    int nr_articles;
    int first;
    int last;
-   int nopost;
+   bool nopost;
 };
 
 extern int group_init (void);
