@@ -12,7 +12,7 @@
 #include <netdb.h>
 #include "config.h"
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: hostname.c 29 2004-04-24 23:02:38Z patrik $";
 
 char *myname (void)
 {
@@ -50,5 +50,5 @@ char *myname (void)
    }
    if (NULL == host)
       host = strdup("localhost");
-   return (host);
+   return host;
 }
