@@ -13,13 +13,13 @@
 #include <string.h>
 #include "b.h"
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: b.c 29 2004-04-24 23:02:38Z patrik $";
 
 int b_appendl (register struct b *bp, char *str, int len)
 {
    if (NULL == bp->buf)
       if (NULL == (bp->buf = malloc(bp->size = 248)))
-         return (-1);
+         return -1;
       else
          bp->used = 0;
 
@@ -35,7 +35,7 @@ int b_appendl (register struct b *bp, char *str, int len)
       newsize += 16;
       tmp = malloc(newsize);
       if (NULL == tmp)
-         return (-1);
+         return -1;
       memcpy(tmp, bp->buf, bp->used + 1);
       bp->buf = tmp;
       bp->size = newsize;
@@ -43,5 +43,5 @@ int b_appendl (register struct b *bp, char *str, int len)
    memcpy(bp->buf + bp->used, str, len);
    bp->used += len;
    bp->buf[bp->used] = '\0';
-   return (0);
+   return 0;
 }
