@@ -9,6 +9,8 @@
 #include <unistd.h>
 #include "format.h"
 
+static const char ver_ctrl_id[] = "$Id: log.c 29 2004-04-24 23:02:38Z patrik $";
+
 char *progname = 0;
 static char logbuf[1024];
 
@@ -27,7 +29,11 @@ void logv (char *fmt, va_list ap)
    write(2, logbuf, len + 1);
 }
 
-void log (char *fmt, ...)
+/* Renamed log -> log_ in order to avoid the annoying warning
+   "conflicting types for built-in function `log'" that seems
+   to have appeared in gcc 3.3... */
+
+void log_ (char *fmt, ...)
 {
    va_list ap;
 
@@ -42,5 +48,6 @@ void fail (int ex, char *fmt, ...)
 
    va_start(ap, fmt);
    logv(fmt, ap);
+   va_end(ap);
    _exit(ex);
 }
