@@ -11,19 +11,23 @@
 #include <errno.h>
 #include "format.h"
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: openf.c 29 2004-04-24 23:02:38Z patrik $";
 
 static char buf[MAXPATHLEN + 1];
 
 int openf (int mode, int flags, char *fmt, ...)
 {
+   int len;
    va_list ap;
 
    va_start(ap, fmt);
-   if (formatv(buf, sizeof (buf) - 1, fmt, ap) >= sizeof (buf))
+   len = formatv(buf, sizeof (buf) - 1, fmt, ap);
+   va_end(ap);
+
+   if (len >= sizeof (buf))
    {
       errno = ENAMETOOLONG;
-      return (-1);
+      return -1;
    }
-   return (open(buf, flags, mode));
+   return open(buf, flags, mode);
 }
