@@ -23,7 +23,7 @@
 extern char *progname;
 
 extern void logv (char *fmt, va_list ap);
-extern void log (char *fmt, ...);
+extern void log_ (char *fmt, ...);
 extern void fail (int ex, char *fmt, ...);
 extern int writefv (int fd, char *fmt, va_list ap);
 extern int writef (int fd, char *fmt, ...);
