@@ -5,7 +5,9 @@
  * Copyright  2000- Patrik Rdman.
  */
 
-static const char rcsid[] = "$Id$";
+#include <stdlib.h>
+
+static const char ver_ctrl_id[] = "$Id: tokensep.c 40 2004-04-28 18:00:25Z patrik $";
 
 char *tokensep (char **p, char *delim)
 {
@@ -20,7 +22,7 @@ char *tokensep (char **p, char *delim)
    }
    for (start = *p; *start && map[(unsigned) *start]; start++) ;
    if (!*start)
-      return (0);
+      return NULL;
    for (end = start; *end && !map[(unsigned) *end]; end++) ;
    if (*end)
    {
@@ -29,5 +31,5 @@ char *tokensep (char **p, char *delim)
    }
    else
       *p = end;
-   return (start);
+   return start;
 }
