@@ -12,6 +12,6 @@ extern char *snroot;
 extern uid_t snuid;
 extern gid_t sngid;
 
-extern void parameters (int wantwriteperms);
+extern void parameters (bool wantwriteperms);
 
 #endif
