@@ -38,10 +38,10 @@
 #include <format.h>
 #include <opt.h>
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: snexpire.c 29 2004-04-24 23:02:38Z patrik $";
 
 int debug = 0;
-int report = 0;
+bool report = FALSE;
 
 time_t parseexp (char *buf)
 {
@@ -73,7 +73,7 @@ time_t parseexp (char *buf)
             return -1;
    }
    
-   return (time_t) exp;
+   return ((time_t) exp);
 }
 
 static time_t readexp (char *newsgroup)
@@ -95,13 +95,13 @@ static time_t readexp (char *newsgroup)
          if ((t = parseexp(buf)) > -1)
          {
             close(fd);
-            return (t);
+            return t;
          }
          LOG("bad format in %s/.expire", newsgroup);
       }
       close(fd);
    }
-   return (DEFAULT_EXP);
+   return DEFAULT_EXP;
 }
 
 /*
@@ -139,17 +139,17 @@ static int expire (char *newsgroup, time_t age)
    if (maxfile == -1)
    {
       LOG1("expire:group \"%s\" is empty", newsgroup);
-      return (0);
+      return 0;
    }
 
    if (age)
       switch (serial = times_since(newsgroup, time(NULL) - age))
       {
          case -1:
-            log("times_since(%s):%m", newsgroup);
-            return (-1);
+            LOG("times_since(%s):%m", newsgroup);
+            return -1;
          case 1: /* everything is too young */
-            return (0);
+            return 0;
          case 0: /* everything needs to be expired */
             maxfile--; /* but leave one file behind */
             break;
@@ -196,10 +196,10 @@ static int expire (char *newsgroup, time_t age)
       /* Delete the file */
       formats(buf, sizeof (buf) - 1, "%s/%d", newsgroup, file);
       if (-1 == unlink(buf))
-         log("expire:unlink(%s):%m", buf);
+         LOG("expire:unlink(%s):%m", buf);
    }
    times_expire(newsgroup, (maxfile + 1) * ARTSPERFILE);
-   return (0);
+   return 0;
 }
 
 static void usage (void) { fail(1, "Usage:%s [[-exp] newsgroup]...", progname); }
@@ -217,14 +217,14 @@ int main (int argc, char **argv)
          case 'P': log_with_pid(); break;
          case 'd': debug++; break;
          case 'V': version(); _exit(0);
-         case 'v': report = 1; break;
+         case 'v': report = TRUE; break;
          case '0': case '1': case '2': case '3': case '4':
          case '5': case '6': case '7': case '8': case '9':
             goto out;
          default: usage();
       }
 out:
-   parameters(1);
+   parameters(TRUE);
 
    if (-1 == chdir(snroot))
       FAIL(2, "Can't chdir(%s):%m", snroot);
@@ -233,7 +233,7 @@ out:
    {
       if (0 == times_init())
       {
-         if (0 == dh_open(0, 0))
+         if (0 == dh_open(NULL, FALSE))
          {
             if (0 == group_init())
                break;
@@ -263,7 +263,7 @@ out:
 
       if (!is_valid_group(argv[i]) && strcmp(argv[i], JUNK_GROUP))
       {
-         log("%s is not a valid newsgroup", argv[i]);
+         LOG("%s is not a valid newsgroup", argv[i]);
          errors++;
       }
       else
