@@ -26,19 +26,19 @@
 #include <format.h>
 #include <opt.h>
 
+static const char ver_ctrl_id[] = "$Id: snfetch.c 40 2004-04-28 18:00:25Z patrik $";
+
 struct readln input = { 0, };
-int newsbatch = 0;
+bool newsbatch = FALSE;
 int pipelining = 0;
 int debug = 0;
 int bytesin = 0;
 int nrhave;
 int nrdup;
 
-static const char rcsid[] = "$Id$";
-
 static void nomem (void) { fail(2, "No memory"); }
-static void badresponse (char *cmd) { log("Bad response to %s, got \"%s\"", cmd, args_inbuf); _exit(3); }
-static void badoutput (char *cmd, char *line) { log("Bad output to %s, got \"%s\"", cmd, line); }
+static void badresponse (char *cmd) { LOG("Bad response to %s, got \"%s\"", cmd, args_inbuf); _exit(3); }
+static void badoutput (char *cmd, char *line) { LOG("Bad output to %s, got \"%s\"", cmd, line); }
 
 static int doread (void)
 {
@@ -51,13 +51,13 @@ static int doread (void)
       case 0:
          fail(3, "invalid reply :%s", args_inbuf);
    }
-   return (i);
+   return i;
 }
 
 static struct art {
    int serial;
    char *id;
-} *arts = 0;
+} *arts = NULL;
 
 static int nr_arts = 0;
 
@@ -101,7 +101,7 @@ void sendstat (int from, int to)
    int i, n, p, stopwriting, startreading;
 
    if (debug)
-      log("sendstat:trying");
+      LOG("sendstat:trying");
    if ((p = to - from) > pipelining)
       p = pipelining;
 
@@ -196,7 +196,7 @@ void readprint (void)
    static struct b b = { 0, };
    char *endline;
    int endlinelen;
-   int seenbreak;
+   bool seenbreak;
 
    if (newsbatch)
    {
@@ -210,7 +210,7 @@ void readprint (void)
    }
 
    b.used = 0;
-   seenbreak = 0;
+   seenbreak = FALSE;
    while ((len = readln(&input, &line, '\n')) > 1)
    {
       bytesin += len;
@@ -219,7 +219,7 @@ void readprint (void)
          if ('\r' == line[len - 1])
             line[--len] = '\0';
       if (0 == len)
-         seenbreak = 1;
+         seenbreak = TRUE;
       if ('.' == *line)
       {
          if (1 == len)
@@ -311,7 +311,7 @@ int fetch (int *nr)
       }
    }
    *nr = collected;
-   return (last);
+   return last;
 }
 
 static int cat (char *fn, int *val)
@@ -322,19 +322,19 @@ static int cat (char *fn, int *val)
    int fd = open(fn, O_RDONLY);
 
    if (-1 == fd)
-      return (-1);
+      return -1;
    i = read(fd, buf, sizeof (buf) - 1);
    close(fd);
    if (-1 == i)
-      return (-1);
+      return -1;
    buf[i] = '\0';
    *val = strtoul(buf, &end, 10);
    if (*end && *end != '\n')
-      return (-1);
-   return (0);
+      return -1;
+   return 0;
 }
 
-void usage(void) { fail(1, "Usage:%s [-r] [-c depth] [-t timeout] newsgroup [serial [max]]", progname); }
+void usage (void) { fail(1, "Usage:%s [-r] [-c depth] [-t timeout] newsgroup [serial [max]]", progname); }
 
 int main (int argc, char **argv)
 {
@@ -346,7 +346,7 @@ int main (int argc, char **argv)
    int max = -1;
    int timeout = 60;
    int from, to, last, nr;
-   int logpid = 0;
+   bool logpid = FALSE;
    int fd, len;
 
    progname = ((cp = strrchr(argv[0], '/')) ? cp + 1 : argv[0]);
@@ -354,7 +354,7 @@ int main (int argc, char **argv)
    while ((i = opt_get(argc, argv, "tc")) > -1)
       switch (i)
       {
-         case 'r': newsbatch = 1; break;
+         case 'r': newsbatch = TRUE; break;
          case 'd': debug++; break;
          case 'V': version(); _exit(0);
          case 't':
@@ -371,7 +371,7 @@ int main (int argc, char **argv)
             if (pipelining < 0 || *cp)
                usage();
             break;
-         case 'P': logpid = 1; break;
+         case 'P': logpid = TRUE; break;
          default: usage();
       }
    if (opt_ind >= argc)
@@ -401,7 +401,7 @@ int main (int argc, char **argv)
       progname = cp;
    }
 
-   parameters(1);
+   parameters(TRUE);
 
    if (-1 == chdir(snroot) || -1 == chdir(newsgroup))
       fail(2, "chdir(%s/%s):%m", snroot, newsgroup);
@@ -410,12 +410,12 @@ int main (int argc, char **argv)
    {
       if (cat(".serial", &serial) < 0)
       {
-         log("open(.serial):%m");
+         LOG("open(.serial):%m");
          serial = 0;
       }
       else if (serial < 0)
       {
-         log("Bad serial %d changed to 0", serial);
+         LOG("Bad serial %d changed to 0", serial);
          serial = 0;
       }
    }
@@ -425,13 +425,13 @@ int main (int argc, char **argv)
          max = -1;
       else if (max < 0)
       {
-         log("Bad max %d changed to -1", max);
+         LOG("Bad max %d changed to -1", max);
          max = -1;
       }
    }
    if (pipelining < 0)
    {
-      log("Bad pipelining %d changed to 0", pipelining);
+      LOG("Bad pipelining %d changed to 0", pipelining);
       pipelining = 0;
    }
 
@@ -459,10 +459,10 @@ int main (int argc, char **argv)
       fail(0, "No new articles");
    last = 0;
    to += 2; /* look ahead a bit */
-   if (-1 == dh_open("../", 0))
-      log("WARNING:you will have duplicates");
+   if (-1 == dh_open("../", FALSE))
+      LOG("WARNING:you will have duplicates");
    if (serial > to || serial < from)
-      log("out of sync, %d not between %d-%d", serial, last = from, to);
+      LOG("out of sync, %d not between %d-%d", serial, last = from, to);
    else
       from = serial; /* normally taken */
 
@@ -477,13 +477,13 @@ int main (int argc, char **argv)
       fail(0, "Nothing to fetch");
 
    dh_close();
-   log("%d articles (%d bytes) in %d seconds", nr, bytesin, time(0) - t);
+   LOG("%d articles (%d bytes) in %d seconds", nr, bytesin, time(NULL) - t);
    LOG1("new/dup/present = %d/%d/%d", nr, nrdup, nrhave);
 
    if (-1 == (fd = open(".serial.tmp", O_WRONLY | O_CREAT, 0644)))
-      log("open(.serial.tmp):%m");
+      LOG("open(.serial.tmp):%m");
    else if (-1 == (len = writef(fd, "%d\n", last)))
-      log("write(.serial.tmp):%m");
+      LOG("write(.serial.tmp):%m");
    else
    {
       ftruncate(fd, len);
@@ -491,6 +491,6 @@ int main (int argc, char **argv)
       key_free();
       _exit(0);
    }
-   log("Last serial fetched was %d", last);
+   LOG("Last serial fetched was %d", last);
    _exit(2);
 }
