@@ -25,7 +25,7 @@
 #include <statf.h>
 #include <format.h>
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: snget.c 36 2004-04-27 16:52:02Z patrik $";
 
 int debug = 0;
 
@@ -37,7 +37,7 @@ void usage (void)
 
 /* Main function - uses variables and functions from get.c */
 
-int main(int argc, char **argv)
+int main (int argc, char **argv)
 {
    char optdebugbuf[7];
    int n, mark;
@@ -61,7 +61,7 @@ int main(int argc, char **argv)
          case 't':
             if (!opt_arg)
                usage();
-            log("option \"-t %s\" no longer supported", opt_arg);
+            LOG("option \"-t %s\" no longer supported", opt_arg);
             break;
          case 'p':
             if (!opt_arg)
@@ -90,7 +90,7 @@ int main(int argc, char **argv)
                fail(1, "Bad value for max-prime-articles option -m");
             break;
          case 'P':
-            optlogpid = 1;
+            optlogpid = TRUE;
             log_with_pid();
             break;
          default:
@@ -102,7 +102,7 @@ int main(int argc, char **argv)
    if (-1 == dup2(2, 6) || -1 == dup2(2, 7) || -1 == dup2(2, 1))
       fail(2, "Unable to dup standard error:%m");
 
-   parameters(1);
+   parameters(TRUE);
    if (-1 == chdir(snroot))
       fail(2, "chdir(%s):%m", snroot);
    init();
@@ -154,8 +154,8 @@ int main(int argc, char **argv)
          max = throttle_setfds(&rset);
          if (sigusr)
          {
-            sigusr = 0;
-            log("throttling at %d bytes/sec", throttlerate);
+            sigusr = FALSE;
+            LOG("throttling at %d bytes/sec", throttlerate);
          }
       }
       else
@@ -163,13 +163,13 @@ int main(int argc, char **argv)
       
       tv.tv_sec = 1;
       tv.tv_usec = 0;
-      if (select(max + 1, &rset, 0, 0, &tv) > 0)
+      if (select(max + 1, &rset, NULL, NULL, &tv) > 0)
          if (throttlerate)
             throttle(&rset);
       
       if (sigchld || 1 == mark % 10)
       {
-         sigchld = 0;
+         sigchld = FALSE;
          while (reap() == 0)
             ;
       }
