@@ -27,7 +27,7 @@
 #include <statf.h>
 #include <time.h>
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: sngetd.c 29 2004-04-24 23:02:38Z patrik $";
 
 int debug = 0;
 static int fifofd;
@@ -39,7 +39,7 @@ struct get {
    char group[1];
 };
 
-static struct get *recently = 0;
+static struct get *recently = NULL;
 
 static void readgroup (void)
 {
@@ -112,7 +112,7 @@ static void readgroup (void)
                   if (tmp)
                      tmp->next = 0;
                   else
-                     recently = 0;
+                     recently = NULL;
                   do
                   {
                      tmp = gp->next;
@@ -138,7 +138,7 @@ static void readgroup (void)
                      recently = gp;
                   }
                   else
-                     log("Oops, no memory to remember I'm fetching %s", p);
+                     LOG("Oops, no memory to remember I'm fetching %s", p);
                }
             }
             else
@@ -188,7 +188,7 @@ int main (int argc, char **argv)
          case 't':
             if (!opt_arg)
                usage();
-            log("option \"-t %s\" no longer supported", opt_arg);
+            LOG("option \"-t %s\" no longer supported", opt_arg);
             break;
          case 'p':
             if (!opt_arg)
@@ -217,7 +217,7 @@ int main (int argc, char **argv)
                fail(1, "Bad value for max-prime-articles option -m");
             break;
          case 'P':
-            optlogpid = 1;
+            optlogpid = TRUE;
             log_with_pid();
             break;
          default:
@@ -228,7 +228,7 @@ int main (int argc, char **argv)
    open("/dev/null", O_RDONLY);
    if (-1 == dup2(2, 6) || -1 == dup2(2, 7) || -1 == dup2(2, 1))
       fail(2, "Can't dup standard error:%m");
-   parameters(1);
+   parameters(TRUE);
    if (-1 == chdir(snroot))
       fail(2, "chdir(%s):%m", snroot);
    fifofd = open(".fifo", O_RDWR);
@@ -258,7 +258,7 @@ int main (int argc, char **argv)
     * Not very neighbourly...
     */
    
-   optnocache = 1;
+   optnocache = TRUE;
 
    for (mark = 0;; mark++)
    {
@@ -270,7 +270,7 @@ int main (int argc, char **argv)
 
       if (sigchld || 1 == mark % 20)
       { /* Can't avoid signal loss */
-         sigchld = 0;
+         sigchld = FALSE;
          while (0 == reap()) ;
       }
 
@@ -284,8 +284,8 @@ int main (int argc, char **argv)
             max = fifofd;
          if (sigusr)
          {
-            sigusr = 0;
-            log("throttling at %d bytes/sec", throttlerate);
+            sigusr = FALSE;
+            LOG("throttling at %d bytes/sec", throttlerate);
          }
       }
       else
@@ -293,7 +293,7 @@ int main (int argc, char **argv)
 
       tv.tv_sec = 5;
       tv.tv_usec = 0;
-      if (select(max + 1, &rset, 0, 0, &tv) > -1)
+      if (select(max + 1, &rset, NULL, NULL, &tv) > -1)
       {
          if (throttlerate)
             throttle(&rset);
