@@ -42,9 +42,9 @@
 
 int debug = 0;
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: snntpd.c 36 2004-04-27 16:52:02Z patrik $";
 
-int posting_ok = 0;
+bool posting_ok = FALSE;
 char *client_ip;
 char *me;
 struct readln input;
@@ -140,13 +140,13 @@ void do_quit (void)
 
 /* Not quite safe to do this... */
 
-static int checkservice = 0;
+static bool checkservice = FALSE;
 
 static void handler (int signum)
 {
    if (SIGHUP == signum)
    {
-      checkservice = 1;
+      checkservice = TRUE;
       return;
    }
    dh_close();
@@ -194,13 +194,13 @@ static void docheckservice (void)
       _exit(0);
    }
    if (0 == stat(".nopost", &st))
-      posting_ok = 0;
+      posting_ok = FALSE;
    else if ((p = getenv("POSTING_OK")))
-      posting_ok = 1;
+      posting_ok = TRUE;
    else
-      posting_ok = 0;
+      posting_ok = FALSE;
    openfifo();
-   checkservice = 0;
+   checkservice = FALSE;
 }
 
 static void init (void)
@@ -215,7 +215,7 @@ static void init (void)
 
    if (-1 == chdir(snroot))
       FAIL(2, "chdir(%s):%m", snroot);
-   (void) dh_open(0, 0);
+   (void) dh_open(NULL, FALSE);
    if (-1 == group_init())
    {
       dh_close();
@@ -247,38 +247,38 @@ static int getallgroups (void)
 
    if (!(dir = opendir(".")))
    {
-      log("getallgroups:opendir(%s):%m", snroot);
-      return (-1);
+      LOG("getallgroups:opendir(%s):%m", snroot);
+      return -1;
    }
    for (nr_keys = 0; (dp = readdir(dir)); nr_keys++)
       if (is_valid_group(gr = dp->d_name))
          if (-1 == key_add(&gr, strlen(gr)))
             fail(2, "No memory");
    closedir(dir);
-   return (0);
+   return 0;
 }
 
-static void usage(void) { fail(1, "Usage:%s [-S] [-t timeout]", progname); }
+static void usage (void) { fail(1, "Usage:%s [-S] [-t timeout]", progname); }
 
 int main (int argc, char **argv)
 {
    int i;
    char *cp;
-   int greeting;
+   bool greeting;
    int tmo = 600;
 
    progname = ((cp = strrchr(argv[0], '/')) ? cp + 1 : argv[0]);
 
-   parameters(1);
+   parameters(TRUE);
 
-   greeting = 1;
+   greeting = TRUE;
    while ((i = opt_get(argc, argv, "t")) > -1)
       switch (i)
       {
          case 'P': log_with_pid(); break;
          case 'd': debug++; break;
          case 'V': version(); _exit(0);
-         case 'S': greeting = 0; break;
+         case 'S': greeting = FALSE; break;
          case 't':
             if (!opt_arg)
                fail(1, "Need value for \"t\"");
@@ -301,7 +301,7 @@ int main (int argc, char **argv)
          dup2(1, 2);
          close(lg[1]);
          execvp(argv[opt_ind], argv + opt_ind);
-         log("exec(%s):%m", argv[opt_ind]);
+         LOG("exec(%s):%m", argv[opt_ind]);
          _exit(2);
       }
       close(lg[0]);
@@ -383,21 +383,21 @@ int topline (char *group, char *fn, char *buf, int size)
    else
       fd = openf(0, O_RDONLY, "%s/%s", group, fn);
    if (-1 == fd)
-      return (-1);
+      return -1;
    i = read(fd, buf, size - 1);
    close(fd);
    if (i <= 0)
-      return (i);
+      return i;
    buf[i] = '\0';
    if ((cp = strchr(buf, '\n')))
    {
       *cp = '\0';
       return (cp - buf);
    }
-   return (i);
+   return i;
 }
 
-char *currentgroup = 0;
+char *currentgroup = NULL;
 int currentserial = -1; /* this may be set by others */
 struct group currentinfo = { 0, };
 
@@ -411,19 +411,19 @@ int make_current (char *group)
    {
       if (!(currentgroup = malloc(GROUPNAMELEN + 1)))
       {
-         log("make_current:no memory");
+         LOG("make_current:no memory");
          return -1;
       }
       strcpy(currentgroup, "no.group.selected.yet");   /* Better than random crap... */
    }
    /* prevent =junk from being selected */
    if (!key_exists(group, strlen(group)))
-      return (-1);
+      return -1;
    if (-1 == group_info(group, &currentinfo))
-      return (-1);
+      return -1;
    strcpy(currentgroup, group);
    currentserial = -1;
-   return (0);
+   return 0;
 }
 
 int pipefork (int p[2])
@@ -433,8 +433,8 @@ int pipefork (int p[2])
       int pid;
 
       if ((pid = fork()) > -1)
-         return (pid);
+         return pid;
       close(p[0]);
    }
-   return (-1);
+   return -1;
 }
