@@ -8,7 +8,7 @@
 #ifndef SNNTPD_H
 #define SNNTPD_H
 
-extern int posting_ok;
+extern bool posting_ok;
 extern char *client_ip;
 extern char *me;
 extern struct readln input;
