@@ -42,7 +42,7 @@
 
 int debug = 0;
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: snscan.c 29 2004-04-24 23:02:38Z patrik $";
 
 char *host;
 int errors = 0;
@@ -61,14 +61,14 @@ int snscan (char *newsgroup, int serial)
 {
    struct article a;
    char *id;
-   char *e = 0;
+   char *e = NULL;
 
    if (gimme(newsgroup, serial, &a))
-      return (1);
+      return 1;
    if (*a.head && !art_bodyiscorrupt(a.body, a.blen))
       if ((id = art_findfield(a.head, "Message-ID")))
          if (writef(1, "%s %d %s\n", newsgroup, serial, *id ? id : "<0>") > 0)
-            return (0);
+            return 0;
          else
             fail(2, "write error:%m");
       else
@@ -77,7 +77,7 @@ int snscan (char *newsgroup, int serial)
       e = "Corrupt article %s:%d";
    LOG(e, newsgroup, serial);
    errors++;
-   return (-1);
+   return -1;
 }
 
 static int print_native (struct article *ap, char *host, char *newsgroup, int serial)
@@ -109,7 +109,7 @@ static int print_native (struct article *ap, char *host, char *newsgroup, int se
    v[i].iov_len = 3;
    i++;
 
-   return (writev(1, v, i));
+   return writev(1, v, i);
 }
 
 static int print_batch (struct article *ap, char *host, char *newsgroup, int serial)
@@ -153,25 +153,25 @@ static int print_batch (struct article *ap, char *host, char *newsgroup, int ser
    v[1].iov_len = b.used;
    e = writev(1, v, 2);
    free(b.buf);
-   return (e);
+   return e;
 
 fail:
    if (b.buf)
       free(b.buf);
-   return (-1);
+   return -1;
 }
 
 int sncat (char *newsgroup, int serial)
 {
    struct article a;
-   char *e = 0;
+   char *e = NULL;
 
    if (gimme(newsgroup, serial, &a))
-      return (1);
+      return 1;
    if (!art_bodyiscorrupt(a.body, a.blen))
       if (0 == body(&a.body, &a.blen))
          if (print(&a, host, newsgroup, serial))
-            return (0);
+            return 0;
          else
             fail(2, "write error:%m");
       else
@@ -180,7 +180,7 @@ int sncat (char *newsgroup, int serial)
       e = "Corrupt body in %s:%d";
    LOG(e, newsgroup, serial);
    errors++;
-   return (-1);
+   return -1;
 }
 
 int sncancel (char *newsgroup, int serial)
@@ -194,13 +194,13 @@ int sncancel (char *newsgroup, int serial)
    char *p;
 
    if (-1 == art_gimmenoderef(newsgroup, serial, &a))
-      return (1);
+      return 1;
    id = art_findfield(a.head, "Message-ID");
    if (!id || !*id)
    {
       LOG1("sncancel:Can't find ID in %s:%d", newsgroup, serial);
       errors++;
-      return (-1);
+      return -1;
    }
    if ('<' == *id)
       id++;
@@ -221,7 +221,7 @@ int sncancel (char *newsgroup, int serial)
             d.messageid = id;
             if (dh_delete(&d))
                LOG1("dh_delete(<%s>):%m", id);
-            return (0);
+            return 0;
          }
          else
          {
@@ -236,9 +236,9 @@ int sncancel (char *newsgroup, int serial)
       close(fd);
    }
    else if (ENOENT != errno)
-      log("sncancel:open(%s):%m", path);
+      LOG("sncancel:open(%s):%m", path);
    errors += er;
-   return (-1);
+   return -1;
 }
 
 static int range (char *spec, int *hi, int *lo)
@@ -246,21 +246,21 @@ static int range (char *spec, int *hi, int *lo)
    char *cp;
 
    if (*spec < '0' || *spec > '9')
-      return (-1);
+      return -1;
    if ((*lo = strtol(spec, &cp, 10)) < 0)
-      return (-1);
+      return -1;
    if (!*cp)
       return (*hi = 0);
    if ('-' != *cp)
-      return (-1);
+      return -1;
    spec = cp + 1;
    if (!*spec)
    {
       *hi = -1;
-      return (0);
+      return 0;
    }
    if ((*hi = strtol(spec, &cp, 10)) < 0)
-      return (-1);
+      return -1;
    return (*cp ? -1 : 0);
 }
 
@@ -270,16 +270,16 @@ static time_t timefmt (char *str)
    char *p = str;
 
    if (*p < '0' || *p > '9')
-      return (-1);
+      return -1;
    tm.tm_year = strtoul(p, &str, 10);
    if (!str || !*str)
-      return (-1);
+      return -1;
    if (tm.tm_year > 1900)
       tm.tm_year -= 1900;
    p = ++str;
    tm.tm_mon = strtoul(p, &str, 10);
    if (!str || !*str)
-      return (-1);
+      return -1;
    tm.tm_mon--;
    p = ++str;
    tm.tm_mday = strtoul(p, &str, 10);
@@ -298,18 +298,18 @@ static time_t timefmt (char *str)
          }
       }
    }
-   return (mktime(&tm));
+   return mktime(&tm);
 }
 
 int getnoaliases (char *group, int serial, struct article *ap)
 {
    if (-1 == art_gimmenoderef(group, serial, ap))
-      return (1);
+      return 1;
    if (ap->blen > 0)
-      return (0);
+      return 0;
    if (0 == strncasecmp(ap->head, "Message-ID:", 11))
-      return (1);
-   return (0);
+      return 1;
+   return 0;
 }
 
 int earliest (char *ng, time_t since)
@@ -320,12 +320,12 @@ int earliest (char *ng, time_t since)
    {
       if (-1 == start)
       {
-         log("times_since(%s):%m?", ng);
+         LOG("times_since(%s):%m?", ng);
          errors++;
       }
-      return (0);
+      return 0;
    }
-   return (start);
+   return start;
 }
 
 int main (int argc, char **argv)
@@ -334,16 +334,16 @@ int main (int argc, char **argv)
    int (*doit) (char *, int);
    int i, outfd;
    char *cp;
-   int useid = 0;
+   bool useid = FALSE;
    struct group g;
-   int dhro;
+   bool dhro;
 
    progname = ((cp = strrchr(argv[0], '/')) ? cp + 1 : argv[0]);
 
-   dhro = 1;
+   dhro = TRUE;
    if (0 == strcmp(progname, "sncancel"))
    {
-      dhro = 0;
+      dhro = FALSE;
       doit = sncancel;
    }
    else if (0 == strcmp(progname, "snscan"))
@@ -372,7 +372,7 @@ int main (int argc, char **argv)
          case 'd': debug++; break;
          case 'n': gimme = getnoaliases; break;
          case 'V': version(); _exit(0);
-         case 'i': useid = 1; break;
+         case 'i': useid = TRUE; break;
          case 'r': print = print_batch; break;
          case 'o':
             if (!opt_arg)
@@ -400,7 +400,7 @@ int main (int argc, char **argv)
       fail(2, "group_init:%m");
 
    if (!dhro || useid)
-      if (-1 == dh_open(0, dhro))
+      if (-1 == dh_open(NULL, dhro))
          fail(2, "Can't open database");
 
    if (useid)
@@ -452,13 +452,13 @@ int main (int argc, char **argv)
          *colon++ = '\0';
       if (strchr(newsgroup, '/') || strstr(newsgroup, ".."))
       {
-         log("Bad newsgroup name \"%s\"", newsgroup);
+         LOG("Bad newsgroup name \"%s\"", newsgroup);
          errors++;
          continue;
       }
       if (-1 == group_info(newsgroup, &g))
       {
-         log("group \"%s\":%m?", newsgroup);
+         LOG("group \"%s\":%m?", newsgroup);
          errors++;
          continue;
       }
@@ -489,7 +489,7 @@ int main (int argc, char **argv)
             {
                if (range(comma, &hi, &lo))
                {
-                  log("Bad range \"%s\"", comma);
+                  LOG("Bad range \"%s\"", comma);
                   errors++;
                   continue;
                }
