@@ -38,7 +38,7 @@
 #include <out.h>
 #include <b.h>
 
-static const char rcsid[] = "$Id$";
+static const char ver_ctrl_id[] = "$Id: snsend.c 58 2004-07-28 18:56:20Z patrik $";
 
 static char path1[MAXPATHLEN + 1];
 static char path2[MAXPATHLEN + 1];
@@ -53,19 +53,21 @@ static struct ng {
 static struct readln input = { 0, };
 static struct article art = { 0, };
 
-static void nomem(void) { fail(2, "No memory"); }
+static void nomem (void) { fail(2, "No memory"); }
 
 static char *me;
 static int melen;
 static int nrgroups;
 static char *messageid;
-static int check_exist = 0;
+static bool check_exist = FALSE;
 static int pid;
 static struct timeval now;
-static int canalias = 1;
-static int report = 0;
+static bool canalias = TRUE;
+static bool report = FALSE;
 int debug = 0;
 
+#define B_APPENDL(b,str) b_appendl((b), (str), strlen(str))
+
 static ng_t newsgroup_type (char *group)
 {
    struct stat st;
@@ -74,23 +76,23 @@ static ng_t newsgroup_type (char *group)
    if (0 == stat(path1, &st))
    {
       if (S_ISDIR(st.st_mode))
-         return (NG_GLOBAL);
+         return NG_GLOBAL;
       if (S_ISREG(st.st_mode))
       {
          if (S_IXUSR & st.st_mode)
-            return (NG_SPECIALX);
+            return NG_SPECIALX;
          else
-            return (NG_SPECIAL);
+            return NG_SPECIAL;
       }
       if (S_ISFIFO(st.st_mode))
-         return (NG_FIFO);
-      return (NG_UNKNOWN);
+         return NG_FIFO;
+      return NG_UNKNOWN;
    }
    if (ENOTDIR == errno)
-      return (NG_UNKNOWN);
+      return NG_UNKNOWN;
    if (0 == stat(group, &st) && S_ISDIR(st.st_mode))
-      return (NG_LOCAL);
-   return (NG_UNKNOWN);
+      return NG_LOCAL;
+   return NG_UNKNOWN;
 }
 
 /* -----------------------------------------------------
@@ -103,8 +105,8 @@ static int writeart (int fd)
       if (write(fd, "\r\n", 2) > -1)
          if (art.body && write(fd, art.body, art.blen) > -1)
             if (write(fd, ".\r\n", 3) > -1)
-               return (0);
-   return (-1);
+               return 0;
+   return -1;
 }
 
 static int store_global (char *group)
@@ -115,15 +117,15 @@ static int store_global (char *group)
    formats(path1, sizeof (path1) - 1, "%s/.outgoing/$%u.%u.%u",
            group, now.tv_sec, now.tv_usec, pid);
    if (0 == stat(path1, &st))
-      return (0);
+      return 0;
    *strrchr(path1, '$') = '+';
    fd = open(path1, O_WRONLY | O_CREAT | O_EXCL, 0644);
    if (-1 == fd)
    {
       if (EEXIST == errno)
       {
-         log("store_global:tmp file %s exists", path1);
-         return (0); /* darn unlikely */
+         LOG("store_global:tmp file %s exists", path1);
+         return 0; /* darn unlikely */
       }
       else
          fail(2, "store_global:open(%s):%m", path1);
@@ -137,16 +139,16 @@ static int store_global (char *group)
       if (-1 == link(path1, path2) && EEXIST != errno)
       {
          er = -1;
-         log("store_global:link(%s,%s):%m", path1, path2);
+         LOG("store_global:link(%s,%s):%m", path1, path2);
       }
    }
    else
-      log("store_global:write(%s):%m", path1);
+      LOG("store_global:write(%s):%m", path1);
 
    (void) unlink(path1);
    if (er)
       _exit(2);
-   return (0);
+   return 0;
 }
 
 static int store_local (char *group)
@@ -160,7 +162,7 @@ static int store_local (char *group)
             if (0 == strcasecmp(group, d.newsgroup))
             {
                LOG1("store_local:<%s> already exists in %s, not storing", messageid, group);
-               return (1);
+               return 1;
             }
    d.serial = sto_add(group ? group : JUNK_GROUP, &art);
    if (-1 == d.serial)
@@ -182,7 +184,7 @@ static int store_local (char *group)
             LOG1("store_local:oops, stored <%s> but it already exists", messageid);
          }
          else
-            log("store_local:can't insert in db for <%s> in %s:%d, %m?",
+            LOG("store_local:can't insert in db for <%s> in %s:%d, %m?",
                 messageid, group, d.serial);
       }
    }
@@ -220,7 +222,7 @@ static int special (char *group, int argv0)
    if (WIFEXITED(s))
    {
       if (0 == WEXITSTATUS(s))
-         return (0);
+         return 0;
       s = WEXITSTATUS(s);
       fail(s, "%s/.outgoing exited with %d", s, s);
    }
@@ -230,8 +232,8 @@ static int special (char *group, int argv0)
    _exit(1); /* dumb compiler */
 }
 
-static int store_special (char *group) { return (special(group, 0)); }
-static int store_specialx(char *group) { return (special(group, 1)); }
+static int store_special (char *group) { return special(group, 0); }
+static int store_specialx (char *group) { return special(group, 1); }
 
 static int store_fifo (char *group)
 {
@@ -247,7 +249,7 @@ static int store_fifo (char *group)
    if (-1 == writeart(fd))
       fail(2, "store_fifo:write(%s):%m", path1);
    close(fd);
-   return (0);
+   return 0;
 }
 
 #define for_each_newsgroup(n) \
@@ -264,7 +266,7 @@ static int localstore (void)
       {
          serial = store_local(newsgroups[i].s);
          if (1 == serial)
-            return (1); /* short circuit dups */
+            return 1; /* short circuit dups */
          if (canalias && art.body)
          {
             art.body = 0;
@@ -275,7 +277,7 @@ static int localstore (void)
          newsgroups[i].s = 0;
          done++;
       }
-   return (done);
+   return done;
 }
 
 /* -----------------------------------------------------
@@ -288,16 +290,16 @@ static void junk_article (void)
 {
    static int have_junk_group = -1;
 
-   log("article <%s> not for any newsgroup", messageid);
+   LOG("article <%s> not for any newsgroup", messageid);
    if (0 == have_junk_group)
       return;
    if (store_local(0) < 0)
    {
       if (debug >= 1)
       {
-         log(">>>");
+         LOG(">>>");
          writeart(2);
-         log("<<<");
+         LOG("<<<");
       }
       have_junk_group = 0;
    }
@@ -371,11 +373,12 @@ static void store___NOT (void)
 
 static void usage (void)
 {
-   fail(2, "Usage: %s [-rcnv]\n"
+   fail(1, "Usage: %s [-rcnva]\n"
         "-r input is in rnews batch format\n"
         "-c when storing to a local newsgroup, check first if it exists\n"
         "-n do nothing; echo articles to descriptor 1\n"
-        "-v for each article, write to descriptor 1 where it went\n", progname);
+        "-v for each article, write to descriptor 1 where it went\n"
+        "-a do not alias crossposts\n", progname);
 }
 
 /* -----------------------------------------------------
@@ -384,8 +387,9 @@ static void usage (void)
 
 int main (int argc, char **argv)
 {
-   int read_article(int);
-   int i, rnews;
+   bool read_article(bool);
+   int i;
+   bool rnews;
    void (*dispatcher) (void);
    char *p;
 
@@ -400,8 +404,8 @@ int main (int argc, char **argv)
       fail(1, "Eh?");
       _exit(1);
    }
-   rnews = 0;
-   canalias = 1;
+   rnews = FALSE;
+   canalias = TRUE;
 
    while ((i = opt_get(argc, argv, "")) > -1)
       switch (i)
@@ -409,16 +413,17 @@ int main (int argc, char **argv)
          case 'd': debug++; break;
          case 'V': version(); _exit(0);
          case 'P': log_with_pid(); break;
-         case 'r': rnews = 1; break;
-         case 'v': report = 1; break;
-         case 'c': check_exist = 1; break;
+         case 'r': rnews = TRUE; break;
+         case 'v': report = TRUE; break;
+         case 'c': check_exist = TRUE; break;
          case 'n': dispatcher = store___NOT; break;
-         case 'a': canalias = 0; break;
+         case 'a': canalias = FALSE; break;
+         default: usage();
       }
    if (opt_ind < argc)
       usage();
 
-   parameters(1);
+   parameters(TRUE);
    if (chdir(snroot))
       fail(2, "chdir(%s):%m", snroot);
    me = myname();
@@ -433,7 +438,7 @@ int main (int argc, char **argv)
       fail(2, "can't initialize store:%m?");
    if (-1 == times_init())
       fail(2, "can't initialize times:%m");
-   (void) dh_open(0, 0);
+   (void) dh_open(NULL, FALSE);
 
    for (gettimeofday(&now, 0); read_article(rnews); gettimeofday(&now, 0))
       dispatcher();
@@ -452,23 +457,23 @@ static struct b body = { 0, };
 static struct b head = { 0, };
 static struct b htmp = { 0, };
 static int body_lines;
-static int have_date;
-static int have_newsgroups;
+static bool have_date;
+static bool have_newsgroups;
 static char *rline;
 static int rlen;
 
 static void badread (void) { fail(2, "can't read article:%m"); }
 static void eof (void) { fail(3, "unexpected end of file"); }
-static void badrnews(void) { fail(3, "bad rnews line"); }
+static void badrnews (void) { fail(3, "bad rnews line"); }
 
-static int first_call;
+static bool first_call;
 
 static void init (void)
 {
    messageid = 0;
-   first_call = 1;
-   body_lines = body.used = head.used = htmp.used =
-       have_date = have_newsgroups = msgid.used = path.used = 0;
+   first_call = TRUE;
+   body_lines = body.used = head.used = htmp.used = msgid.used = path.used = 0;
+   have_date = have_newsgroups = FALSE;
 }
 
 static int getline (void)
@@ -477,18 +482,18 @@ static int getline (void)
 
    len = rlen = readln(&input, &rline, '\n');
    if (0 == rlen)
-      return (0);
+      return 0;
    if (rlen < 0) badread();
    rline[--rlen] = '\0';
    if (rlen > 0)
       if ('\r' == rline[rlen - 1])
          rline[--rlen] = '\0';
-   return (len);
+   return len;
 }
 
 static void appendbody (void)
 {
-   if (b_appendl(&body, rline, rlen) || b_appendl(&body, "\r\n", 2)) nomem();
+   if (b_appendl(&body, rline, rlen) || B_APPENDL(&body, "\r\n")) nomem();
 }
 
 /* Sets newsgroups[]; valid until next call */
@@ -506,7 +511,7 @@ static void parsenewsgroups (char *ng)
       ng++;
 
    ngbuf.used = 0;
-   if (b_appendl(&ngbuf, ng, strlen(ng))) nomem();
+   if (B_APPENDL(&ngbuf, ng)) nomem();
    ng = ngbuf.buf;
 
    for (nrgroups = 0; (p = tokensep(&ng, ",")); nrgroups++)
@@ -550,9 +555,9 @@ static int append (char *line, int len)
 
    if (first_call)
    {
-      first_call = 0;
+      first_call = FALSE;
       if (0 == strncmp(line, "From ", 5))
-         return (0);
+         return 0;
    }
    hlen = check_field(line, len);
    if (!hlen)
@@ -572,63 +577,63 @@ static int append (char *line, int len)
                c--;
             }
             if (!*p) break;
-            if (b_appendl(&htmp, "References: ", sizeof ("References: ") - 1)) nomem();
+            if (B_APPENDL(&htmp, "References: ")) nomem();
             if (b_appendl(&htmp, p + 1, c - 1)) nomem();
-            if (b_appendl(&htmp, "\r\n", 2)) nomem();
-            return (0);
+            if (B_APPENDL(&htmp, "\r\n")) nomem();
+            return 0;
          }
          break;
       }
       HEADER("Path")
       {
          if (path.used)
-            return (0);
+            return 0;
          for (line += hlen + 1, len -= hlen + 1; ' ' == *line; line++, len--) ;
          if (b_appendl(&path, line, len)) nomem();
-         return (0);
+         return 0;
       }
       HEADER("Newsgroups")
       {
          if (have_newsgroups) break; /* XXX ignore or fail? */
          if (b_appendl(&htmp, line, len)) nomem();
-         if (b_appendl(&htmp, "\r\n", 2)) nomem();
-         have_newsgroups = 1;
+         if (B_APPENDL(&htmp, "\r\n")) nomem();
+         have_newsgroups = TRUE;
          parsenewsgroups(line + hlen + 1);
-         return (0);
+         return 0;
       }
       HEADER("X-sn-Newsgroups")
       {
          parsenewsgroups(line + hlen + 1);
-         return (0);
+         return 0;
       }
       HEADER("Message-ID")
       {
-         int c;
+         int len;
 
          if (msgid.used) break; /* XXX */
          for (p = line + hlen + 1; ' ' == *p; p++) ;
-         if ('<' != *p++ || (c = addr_addrspec(p)) <= 0)
+         if ('<' != *p || (len = addr_msgid(p)) <= 0)
          {
-            log("append: will replace bad Message-ID \"%s\"", p - 1);
-            return (0);
+            LOG("append: will replace bad Message-ID \"%s\"", p);
+            return 0;
          }
-         if (b_appendl(&msgid, p, c)) nomem();
+         if (b_appendl(&msgid, p + 1, len - 2)) nomem();
          break;
       }
       if (0 == strncasecmp(line, "X-sn-", 5))
-         return (0);
-      HEADER("Bytes") return (0);
-      HEADER("Lines") return (0);
-      HEADER("Xref") return (0);
-      HEADER("Date") have_date = 1;
+         return 0;
+      HEADER("Bytes") return 0;
+      HEADER("Lines") return 0;
+      HEADER("Xref") return 0;
+      HEADER("Date") have_date = TRUE;
    }
    while (0);
    if (0)
 badline:
-      log("append:bad header \"%s\"", line);
+      LOG("append:bad header \"%s\"", line);
    if (b_appendl(&htmp, line, len)) nomem();
-   if (b_appendl(&htmp, "\r\n", 2)) nomem();
-   return (0);
+   if (B_APPENDL(&htmp, "\r\n")) nomem();
+   return 0;
 }
 
 static int read_nntp (void)
@@ -637,7 +642,7 @@ static int read_nntp (void)
 
    consumed = unfold(&input, append);
    if (0 == consumed)
-      return (0);
+      return 0;
    if (consumed < 0) badread();
 
    for (body_lines = 0;;)
@@ -652,7 +657,7 @@ static int read_nntp (void)
       body_lines++;
       appendbody();
    }
-   return (consumed);
+   return consumed;
 }
 
 static int read_rnews (void)
@@ -660,7 +665,7 @@ static int read_rnews (void)
    int bytes, c, consumed;
 
    if (0 == getline())
-      return (0);
+      return 0;
 
    if ('#' != *rline++) badrnews();
    if ('!' != *rline++) badrnews();
@@ -687,17 +692,22 @@ static int read_rnews (void)
          fail(3, "rnews input overshot");
       body_lines++;
       if ('.' == *rline)
-         if (b_appendl(&body, ".", 1)) nomem();
+         if (B_APPENDL(&body, ".")) nomem();
       appendbody();
    }
-   return (consumed);
+   return consumed;
 }
 
-static void appendhead (char *line, int len) { if (b_appendl(&head, line, len)) nomem(); }
+static void appendhead (char *line, int len)
+{
+   if (b_appendl(&head, line, len)) nomem();
+}
+
+#define APPENDHEAD(str) appendhead((str), strlen(str))
 
 #define PUT2(i,sep) c = i; *p-- = c%10 + '0'; *p-- = c/10 + '0'; *p-- = sep;
 
-int read_article (int rnews)
+bool read_article (bool rnews)
 {
    char buf[80];
    int c, i;
@@ -708,20 +718,20 @@ int read_article (int rnews)
    else
       c = read_nntp();
    if (0 == c)
-      return (0); /* no more */
+      return FALSE; /* no more */
 
    /* fix the headers.  We don't care if there were newsgroups. */
    /* Path: */
-   appendhead("Path: ", sizeof ("Path: ") - 1);
+   APPENDHEAD("Path: ");
    appendhead(me, melen);
    if (path.used)
    {
-      appendhead("!", 1);
+      APPENDHEAD("!");
       appendhead(path.buf, path.used);
    }
    else
       LOG3("created Path header...");
-   appendhead("\r\n", 2);
+   APPENDHEAD("\r\n");
 
    appendhead(htmp.buf, htmp.used);
 
@@ -730,13 +740,13 @@ int read_article (int rnews)
    {
       c = formats(buf, sizeof (buf) - 1, "%x.%x.%x@%s", pid, now.tv_sec, now.tv_usec, me);
       if (b_appendl(&msgid, buf, c)) nomem();
-      appendhead("Message-ID: <", sizeof ("Message-ID: <") - 1);
+      APPENDHEAD("Message-ID: <");
       appendhead(buf, c);
-      appendhead(">\r\n", 3);
-      LOG3("created message ID \"%s\"", buf);
+      APPENDHEAD(">\r\n");
+      LOG1("created Message-ID \"<%s>\"", buf);
    }
    else
-      LOG3("read article \"%s\"", msgid.buf);
+      LOG3("read article \"<%s>\"", msgid.buf);
    messageid = msgid.buf;
 
    /* Date.  strftime(3) uses locale, we don't want that. */
@@ -769,15 +779,15 @@ int read_article (int rnews)
       *p-- = ',';
       p -= 2;
       memcpy(p, days[tmp->tm_wday], 3);
-      appendhead("Date: ", sizeof ("Date: ") - 1);
-      appendhead(p, strlen(p));
-      appendhead(" -0000\r\n", 8);
-      LOG3("added Date to article \"%s\"", messageid);
+      APPENDHEAD("Date: ");
+      APPENDHEAD(p);
+      APPENDHEAD(" -0000\r\n");
+      LOG3("added Date to article \"<%s>\"", messageid);
    }
 
    if (0 == body_lines)
    {
-      if (b_appendl(&body, "\r\n", 2)) nomem();
+      if (B_APPENDL(&body, "\r\n")) nomem();
       body_lines++;
    }
 
@@ -790,5 +800,5 @@ int read_article (int rnews)
    art.hlen = head.used;
    art.body = body.buf;
    art.blen = body.used;
-   return (1);
+   return TRUE;
 }
