@@ -8,7 +8,7 @@
 #ifndef VALID_H
 #define VALID_H
 
-extern int is_valid_name (char *name);
-extern int is_valid_group (char *name);
+extern bool is_valid_name (char *name);
+extern bool is_valid_group (char *name);
 
 #endif
